from setuptools import setup, find_packages

setup(
      name="HttpMessageProcessor",
      version="1.0.0",
      packages=find_packages(where="."),
      install_requires=[
            "MessageProcessor==4.0.0",
            "SimpleHttpRouter==0.3.3",
            'iso8601==0.1.12;python_version<="2.7"',
            'iso8601==2.1.0;python_version>="3.7"',
            'inspect2==0.1.2;python_version<="2.7"',
            'enum34==1.1.10;python_version<="2.7"',
      ],
      url="https://www.e-deploy.com.br",
      author="Eduardo Almeida",
      author_email="eduardo.almeida@e-deploy.com.br"
)
